| get-results | R Documentation |
get_results() extracts the results of a SA-item.
.jsai_results() extracts specific output of the model of the SA-item.
.jsai_jresults() extracts the Java object of the results of a SA-item.
get_results(jsai)
.jsai_results(jsai, items = NULL)
.jsai_jresults(jsai)
jsai |
Java SA-item object. |
items |
vector of characters containing the variables to extract.
See |
List with all the results of the adjustment.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.