| jws_new | R Documentation |
Functions creating a 'JDemetra+' Workspace (jws_new()) and
adding a new SA-Processing (jws_sap_new()). A modelling context can be
added to a workspace, it will be valid for all its SA-Processings.
jws_new(modelling_context = NULL)
jws_sap_new(jws, name)
modelling_context |
a list of variables and calendars |
jws |
a Javaworkspace object. |
name |
name of the new SA-Processing to be added (character). |
A modelling context is a list of variables to be used as external regressors
in modelling processes (Reg-Arima or Tramo) or calendars to be used to generate calendar regressors.
It can be created with rjd3toolkit::modelling_context() function or retrieved from another
workspace ((set_context))
Returns a Javaobject workspace or SA-Processing.
More information on workspaces in JDemetra+ Graphical User Interface: https://doc.jdemetra.org/t-gui-sa-modelling-features/
read_workspace(), read_sap()
# Create an empty 'JDemetra+' Workspace
jws <- jws_new()
# Add an empty SA-Processing
jsap <- jws_sap_new(jws, "sap1")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.