| read_calendars | R Documentation |
The calendar file is a xml file like the one JDemetra+ would write when defining a calendar in the Graphical User Interface.
read_calendars(file)
file |
path to a calendar file (in xml format) |
a list of JD3_CALENDAR objects
file <- system.file("workspaces", "workspace_test", "Calendars",
"Calendars.xml", package = "rjd3workspace")
my_calendar <- read_calendars(file)
my_calendar
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.