read_variables: Read auxiliary regressors file

View source: R/utils.R

read_variablesR Documentation

Read auxiliary regressors file

Description

The variables (regressors) file is a xml file like the one JDemetra+ would write when setting-up user defined regressors in the Graphical User Interface.

Usage

read_variables(file)

Arguments

file

xml format

Value

A named list of time series objects.

Examples


file <- system.file("workspaces", "workspace_test", "Variables",
                    "Vars-1.xml", package = "rjd3workspace")
my_regressors <- read_variables(file)
class(my_regressors)
str(my_regressors)


rjd3workspace documentation built on July 17, 2026, 9:07 a.m.