rjd3workspace-package: rjd3workspace: Wrangling 'JDemetra+ 3.x' Workspaces

rjd3workspace-packageR Documentation

rjd3workspace: Wrangling 'JDemetra+ 3.x' Workspaces

Description

logo

R Interface to 'JDemetra+ 3.x'(https://github.com/jdemetra). It offers several functions to manipulate 'JDemetra+' workspaces, which can be read by the software and can store several seasonal adjusted series along with user-defined calendars or regression variables.

Author(s)

Maintainer: Tanguy Barthelemy timeserieswithjdemetraandr@gmail.com [artist]

Authors:

See Also

Useful links:


rjd3workspace documentation built on July 17, 2026, 9:07 a.m.