tramo_read_spec: Read a Tramo specification file

View source: R/utils.R

tramo_read_specR Documentation

Read a Tramo specification file

Description

The specification file is a xml file like the one JDemetra+ would write when defining a specification in the Graphical User Interface.

Usage

tramo_read_spec(file)

Arguments

file

xml format,

Value

list

Examples


file <- system.file("workspaces", "workspace_test", "TramoSpec",
                    "TramoSpec-1.xml", package = "rjd3workspace")
my_spec<- tramo_read_spec(file)
class(my_spec)
str(my_spec)


rjd3workspace documentation built on July 17, 2026, 9:07 a.m.