| x13_write_spec | R Documentation |
The specification file is a xml file like the one JDemetra+ would write when defining a specification in the Graphical User Interface.
x13_write_spec(spec, file)
spec |
a specification created with |
file |
xml format |
NULL returned invisibly
# Creating a spec from default
x13_spec <- rjd3x13::x13_spec("rsa3")
# Forcing multiplicative model
x13_spec_d <- rjd3toolkit::set_transform(
x13_spec ,
fun = "Log",
outliers = TRUE
)
# Writing the specification in a xml file
spec_path <- tempfile(fileext = ".xml")
x13_write_spec(x13_spec_d, file = spec_path)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.