| add_variables | R Documentation |
Adds a single time series variable to a specified group within a JD+ workspace..
add_variables(jws, group, name, y, overwrite = FALSE)
jws |
A JD+ workspace object (Java pointer). |
group |
A character string indicating the name of the group in which to store the variable. |
name |
A character string naming the variable. |
y |
A |
overwrite |
a Boolean to indicate whether a variable already present should be replaced |
For the time being, if the group does not already exist, a new group is
created, but the group will be named after name, not group.
No return value (NULL returned invisibly). This function is
used for its side effect of modifying the workspace.
Cannot add multiple variables at once.
Does not support dynamic ts objects with metadata.
If group does not exist, a new group is created but named after the variable name, not the intended group.
rjd3toolkit::modelling_context() to create multiple variables and
groups at once, and read_variables(), write_variables() to import/export
variables.
# Load a Workspace
file <- system.file("workspaces", "workspace_test.xml", package = "rjd3workspace")
jws <- jws_open(file)
add_variables(jws = jws, group = "reg1", y = AirPassengers, name = "x1")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.