Skip to contents

get_results() extracts the results of a SA-item. .jsai_results() extracts specific output of the model of the SA-item. .jsai_jresults() extracts the Java object of the results of a SA-item.

Usage

get_results(jsai)

.jsai_results(jsai, items = NULL)

.jsai_jresults(jsai)

Arguments

jsai

Java SA-item object.

items

vector of characters containing the variables to extract. See rjd3x13::x13_dictionary() or rjd3tramoseats::tramoseats_dictionary(). By default, extracts all the possible variables.