| read_variables | R Documentation |
The variables (regressors) file is a xml file like the one JDemetra+ would write when setting-up user defined regressors in the Graphical User Interface.
read_variables(file)
file |
xml format |
A named list of time series objects.
file <- system.file("workspaces", "workspace_test", "Variables",
"Vars-1.xml", package = "rjd3workspace")
my_regressors <- read_variables(file)
class(my_regressors)
str(my_regressors)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.