| tramoseats_write_spec | R Documentation |
The specification file is a xml file like the one JDemetra+ would write when defining a specification in the Graphical User Interface.
tramoseats_write_spec(spec, file)
spec |
a specification created with |
file |
xml format |
NULL returned invisibly
# Creating a spec from default
tramoseats_spec <- rjd3tramoseats::tramoseats_spec("tr3")
# Forcing multiplicative model
tramoseats_spec_d <- rjd3toolkit::set_transform(
tramoseats_spec ,
fun = "Log",
outliers = TRUE
)
# Writing the specification in a xml file
spec_path <- tempfile(fileext = ".xml")
tramoseats_write_spec(tramoseats_spec_d, file = spec_path)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.